@@ -31,7 +31,7 @@ import datetime
 import random
 from functools import wraps
 import time
-from loguru import logger
+
 
 def logit(func):
     """
@@ -44,7 +44,8 @@ def logit(func):
         t1 = time.time()
         result = func(*args, **kwargs)
         t2 = time.time()
-        logger.info(f'\033[1;30m 耗时:{"%.4f" %(t2 - t1)}秒\033[0m - \033[1;32m{result}\033[0m')
+        date = datetime.datetime.now().strftime('%Y-%m-%d %H:%M:%S')
+        print(f'\033[1;31m {date} \033[0m - \033[4;33m{func.__name__}\033[0m -\033[1;30m 耗时:{"%.4f" %(t2 - t1)}秒\033[0m - \033[1;32m{result}\033[0m')
         return result
     return with_logging
 
@@ -55,7 +56,7 @@ def async_logit(func):
         result =await func(*args, **kwargs)
         t2 = time.time()
         date = datetime.datetime.now().strftime('%Y-%m-%d %H:%M:%S')
-        logger.info(f'\033[1;30m 耗时:{"%.4f" %(t2 - t1)}秒\033[0m - \033[1;32m{result}\033[0m')
+        print(f'\033[1;31m {date} \033[0m - \033[4;33m{func.__name__}\033[0m -\033[1;30m 耗时:{"%.4f" %(t2 - t1)}秒\033[0m - \033[1;32m{result}\033[0m')
         return result
     return with_logging
 
