@@ -27,7 +27,7 @@ def replace_str(start_str,end_str,replace_str,str):
 
 def find_str(start_str,end_str,str):
     """
-    查找以XX开头以XX结尾的字符串
+    查找以XX开头以XX结尾的字符串,返回找到的列表
     """
     re_formula = f"{start_str}.*?{end_str}"
     result = re.findall(re_formula, str)
