@@ -228,7 +228,7 @@ def monitoring_run_time(f):
 
 @retry(stop_max_attempt_number=10)
 def get_taobao_time():
-    """获取苏宁时间{"sysTime2":"2021-01-12 16:41:50","sysTime1":"20210112164150"}"""
+    """获取在线时间{"sysTime2":"2021-01-12 16:41:50","sysTime1":"20210112164150"}"""
     try:
         url = 'http://10.228.84.20:21000/get_local_timestamp'
         ts = requests.get(url)
